<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Stripe\Stripe;
use Stripe\PaymentIntent;
use App\Models\Payment;

class GooglePayController extends Controller
{
    public function checkout()
    {
        return view('googlepay-checkout');
    }

    public function createPaymentIntent(Request $request)
    {
        $request->validate([
            'name' => 'required|string|max:255',
            'email' => 'required|email',
            'amount' => 'required|numeric|min:1',
        ]);

        Stripe::setApiKey(config('services.stripe.secret'));

        try {
            $paymentIntent = PaymentIntent::create([
                'amount' => $request->amount * 100, // Convert to cents
                'currency' => 'usd',
                'payment_method_types' => ['card', 'google_pay'],
                'metadata' => ['integration' => 'google_pay'],
            ]);

            return response()->json([
                'clientSecret' => $paymentIntent->client_secret
            ]);
        } catch (\Exception $e) {
            return response()->json(['error' => $e->getMessage()], 400);
        }
    }

    public function paymentSuccess(Request $request)
    {
        Payment::create([
            'name' => $request->name,
            'email' => $request->email,
            'amount' => $request->amount,
            'stripe_payment_id' => $request->paymentIntentId,
            'status' => 'successful',
        ]);

        return redirect()->route('googlepay.success')->with('success', 'Payment successful!');
    }

    public function success()
    {
        return view('googlepay-success');
    }
}
