<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Google Pay Checkout</title>
    <script src="https://js.stripe.com/v3/"></script>
    <style>
        #google-pay-button-container {
            margin-top: 20px;
        }
    </style>
</head>
<body>
    <h1>Google Pay Checkout</h1>

    <form id="payment-form">
        <?php echo csrf_field(); ?>
        <label>Name:</label>
        <input type="text" id="name" required>

        <label>Email:</label>
        <input type="email" id="email" required>

        <label>Amount (USD):</label>
        <input type="number" id="amount" required>

        <div id="google-pay-button-container"></div>
    </form>

    <script>
        var stripe = Stripe("<?php echo e(config('services.stripe.key')); ?>");

        async function setupGooglePay() {
            var paymentRequest = stripe.paymentRequest({
                country: "US",
                currency: "usd",
                total: {
                    label: "Total",
                    amount: 1000, // Change dynamically
                },
                requestPayerName: true,
                requestPayerEmail: true
            });

            var elements = stripe.elements();
            var googlePayButton = elements.create("paymentRequestButton", {
                paymentRequest: paymentRequest
            });

            paymentRequest.canMakePayment().then(function(result) {
                if (result) {
                    googlePayButton.mount("#google-pay-button-container");
                } else {
                    document.getElementById("google-pay-button-container").innerHTML = "Google Pay is not supported.";
                }
            });

            paymentRequest.on("paymentmethod", async function(ev) {
                try {
                    let response = await fetch("<?php echo e(route('googlepay.payment.intent')); ?>", {
                        method: "POST",
                        headers: {
                            "Content-Type": "application/json",
                            "X-CSRF-TOKEN": document.querySelector('input[name="_token"]').value
                        },
                        body: JSON.stringify({
                            name: document.getElementById("name").value,
                            email: document.getElementById("email").value,
                            amount: document.getElementById("amount").value
                        })
                    });

                    let data = await response.json();
                    if (data.error) {
                        ev.complete("fail");
                        alert(data.error);
                        return;
                    }

                    const { paymentIntent, error } = await stripe.confirmCardPayment(data.clientSecret, {
                        payment_method: ev.paymentMethod.id
                    });

                    if (error) {
                        ev.complete("fail");
                        alert(error.message);
                    } else {
                        ev.complete("success");

                        await fetch("<?php echo e(route('googlepay.success')); ?>", {
                            method: "POST",
                            headers: {
                                "Content-Type": "application/json",
                                "X-CSRF-TOKEN": document.querySelector('input[name="_token"]').value
                            },
                            body: JSON.stringify({
                                name: document.getElementById("name").value,
                                email: document.getElementById("email").value,
                                amount: document.getElementById("amount").value,
                                paymentIntentId: paymentIntent.id
                            })
                        });

                        window.location.href = "<?php echo e(route('googlepay.success')); ?>";
                    }
                } catch (error) {
                    console.error(error);
                }
            });
        }

        setupGooglePay();
    </script>
</body>
</html>
<?php /**PATH C:\xampp8.2.1\htdocs\laravelnewprojstripe\resources\views/googlepay-checkout.blade.php ENDPATH**/ ?>